import pandas as pd
import numpy as np
import pystan
import matplotlib.pyplot as plt
import seaborn as sb

finnm = input('入力データファイル（*.xlsx）= ')
foutnm = input('画像保存ファイル（*.png）= ')
#
#      Excelファイルの読み込み
#　　　モジュール xlrd がインストール済みであること
#
xlsx_fl = pd.ExcelFile(finnm)                       #   ExcelファイルからExcelFile型オブジェクトを生成
data_xlsx = pd.read_excel(xlsx_fl,  header = None)  #   ExcelFile型オブジェクトからDataFrame型オブジェクトを生成
data = data_xlsx.values                             #   Dataframe型オブジェクトからnumpyの配列オブジェクトを生成
print('\n', data)

VarName1 = data[0, 1]
VarName2 = data[0, 2]
print(VarName1, VarName2)
X = data[1:, 1:3]
X = [[v[0], v[1]] for v in X]
print(X)
    
DataStan = {'N': len(X), 'X': X}

sm = pystan.StanModel(file = 'TwoVarsNormal.stan')
fit = sm.sampling(data = DataStan, n_jobs = 1)
print(fit)

SavedFiles = []

#       日本語表記の設定
plt.rcParams['font.family'] = ['Yu Gothic', 'Noto Sans CJK JP', 'Hiragino Maru Gothic Pro']

mu1_025, mu1_50, mu1_975 = np.percentile(fit['mu1'], [2.5, 50, 97.5])
plt.title(('{0:}の平均値の事後分布'.format(VarName1)) + \
          '\nMed = {0:.2f},  95%CI = [{1:.2f}, {2:.2f}]'.format(
              mu1_50, mu1_025, mu1_975), fontsize = 20)
sb.kdeplot(fit['mu1'])
plt.xlabel(VarName1 + 'の平均値', fontsize = 16)
plt.yticks([])
plt.tight_layout()
plt.savefig(foutnm[:-4] + '_mu.png')
SavedFiles.append(foutnm[:-4] + '_mu1.png')
plt.show()

mu2_025, mu2_50, mu2_975 = np.percentile(fit['mu2'], [2.5, 50, 97.5])
plt.title(('{0:}の平均値の事後分布'.format(VarName2)) + \
          '\nMed = {0:.2f},  95%CI = [{1:.2f}, {2:.2f}]'.format(
              mu2_50, mu2_025, mu2_975), fontsize = 20)
sb.kdeplot(fit['mu2'])
plt.xlabel(VarName2 + 'の平均値', fontsize = 16)
plt.yticks([])
plt.tight_layout()
plt.savefig(foutnm[:-4] + '_mu2.png')
SavedFiles.append(foutnm[:-4] + '_mu2.png')
plt.show()

sgm1_025, sgm1_50, sgm1_975 = np.percentile(fit['sgm1'], [2.5, 50, 97.5])
plt.title(('{0:}の標準偏差の事後分布'.format(VarName1)) + \
          '\nMed = {0:.2f},  95%CI = [{1:.2f}, {2:.2f}]'.format(
              sgm1_50, sgm1_025, sgm1_975), fontsize = 20)
sb.kdeplot(fit['sgm1'])
plt.xlabel(VarName1 + 'の標準偏差', fontsize = 16)
plt.yticks([])
plt.tight_layout()
plt.savefig(foutnm[:-4] + '_sgm1.png')
SavedFiles.append(foutnm[:-4] + '_sgm1.png')
plt.show()

sgm2_025, sgm2_50, sgm2_975 = np.percentile(fit['sgm2'], [2.5, 50, 97.5])
plt.title(('{0:}の標準偏差の事後分布'.format(VarName2)) + \
          '\nMed = {0:.2f},  95%CI = [{1:.2f}, {2:.2f}]'.format(
              sgm2_50, sgm2_025, sgm2_975), fontsize = 20)
sb.kdeplot(fit['sgm2'])
plt.xlabel(VarName2 + 'の標準偏差', fontsize = 16)
plt.yticks([])
plt.tight_layout()
plt.savefig(foutnm[:-4] + '_sgm2.png')
SavedFiles.append(foutnm[:-4] + '_sgm2.png')
plt.show()

rho_025, rho_50, rho_975 = np.percentile(fit['rho'], [2.5, 50, 97.5])
plt.title('相関係数の事後分布' + \
          '\nMed = {0:.2f},  95%CI = [{1:.2f}, {2:.2f}]'.format(
              rho_50, rho_025, rho_975), fontsize = 20)
sb.kdeplot(fit['rho'])
plt.xlabel('相関係数', fontsize = 16)
plt.yticks([])
plt.tight_layout()
plt.savefig(foutnm[:-4] + '_rho.png')
SavedFiles.append(foutnm[:-4] + '_rho.png')
plt.show()

print('\n保存ファイル：')
for nm in SavedFiles:
    print('    ', nm)
print()
