data {
    int N;
    vector[2] X[N];
}
parameters {
    real mu1;
    real mu2;
    real<lower = 0.0> sgm1;
    real<lower = 0.0> sgm2;
    real<lower = -1.0, upper = 1.0> rho;
}
transformed parameters {
    vector[2] Mu;
    cov_matrix[2] Sgm;
    Mu[1] = mu1;
    Mu[2] = mu2;
    Sgm[1][1] = sgm1 * sgm1;
    Sgm[1][2] = rho * sgm1 * sgm2;
    Sgm[2][1] = Sgm[1][2];   // rho * sgm2 * sgm1;
    Sgm[2][2] = sgm2 * sgm2;
}
model {
    mu1 ~ normal(0.0, 10000.0);
    mu2 ~ normal(0.0, 10000.0);
    sgm1 ~ exponential(0.0001);
    sgm2 ~ exponential(0.0001);
    rho ~ uniform(-1.0, 1.0);
    for (i in 1:N)
        X[i] ~ multi_normal(Mu, Sgm);
}
